sumo.plotting package
======================

Module contents
---------------

.. automodule:: sumo.plotting
    :members:
    :undoc-members:
    :show-inheritance:


Submodules
----------

sumo.plotting.bs\_plotter module
---------------------------------

.. automodule:: sumo.plotting.bs_plotter
    :members:
    :undoc-members:
    :show-inheritance:

sumo.plotting.dos\_plotter module
----------------------------------

.. automodule:: sumo.plotting.dos_plotter
    :members:
    :undoc-members:
    :show-inheritance:

sumo.plotting.optics\_plotter module
-------------------------------------

.. automodule:: sumo.plotting.optics_plotter
    :members:
    :undoc-members:
    :show-inheritance:

sumo.plotting.phonon\_bs\_plotter module
-----------------------------------------

.. automodule:: sumo.plotting.phonon_bs_plotter
    :members:
    :undoc-members:
    :show-inheritance:
